@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Asana
   module Authentication
     module OAuth2
@@ -24,8 +26,7 @@ module Asana
         #
         # Returns nothing.
         def configure(connection)
-          connection.authorization :Bearer, @token
-          connection.request :oauth2, token_type: 'bearer'
+          connection.request :authorization, 'Bearer', @token
         end
       end
     end
