@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Asana
   module Authentication
     # Public: Represents an API token authentication mechanism.
@@ -13,7 +15,7 @@ module Asana
       #
       # Returns nothing.
       def configure(connection)
-        connection.basic_auth(@token, '')
+        connection.request :authorization, :basic, @token, ''
       end
     end
   end
