@@ -1,3 +1,7 @@
+# frozen_string_literal: true
+
+require 'faraday/multipart'
+
 module Asana
   module Resources
     # Internal: Mixin to add the ability to upload an attachment to a specific
@@ -11,8 +15,6 @@ module Asana
       # options  - [Hash] the request I/O options
       # data     - [Hash] extra attributes to post
       #
-      # rubocop:disable Metrics/AbcSize
-      # rubocop:disable Metrics/MethodLength
       def attach(filename: required('filename'),
                  mime: required('mime'),
                  io: nil, options: {}, **data)
@@ -21,9 +23,9 @@ module Asana
                    path = File.expand_path(filename)
                    raise ArgumentError, "file #{filename} doesn't exist" unless File.exist?(path)
 
-                   Faraday::FilePart.new(path, mime)
+                   Faraday::Multipart::FilePart.new(path, mime)
                  else
-                   Faraday::FilePart.new(io, mime, filename)
+                   Faraday::Multipart::FilePart.new(io, mime, filename)
                  end
 
         response = client.post("/#{self.class.plural_name}/#{gid}/attachments",
@@ -33,8 +35,6 @@ module Asana
 
         Attachment.new(parse(response).first, client: client)
       end
-      # rubocop:enable Metrics/MethodLength
-      # rubocop:enable Metrics/AbcSize
     end
   end
 end
