@@ -14,7 +14,7 @@ module Asana
       class << self
         # Returns the plural name of the resource.
         def plural_name
-          'typeaheads'
+          'typeahead'
         end
       end
     end
